<?php
/**
 * @file
 * Authcache personalized blocks administrative interface.
 */

/**
 * Authcache personalized blocks overview page.
 */
function authcache_block_admin_blocks() {
  drupal_set_title(t('Authcache personalized blocks'));
  drupal_add_css(drupal_get_path('module', 'authcache_block') . '/authcache_block.admin.css');

  // Get the current default theme.
  $themes = list_themes();
  $default_theme = variable_get('theme_default');
  $theme = $themes[$default_theme];

  $page['header']['#markup'] = '<p>' . t('<a href="@blocks_link">Blocks</a> may be configured to load using Ajax or ESI. This is useful for dynamic or user-centric content.', array('@blocks_link' => url('admin/structure/block'))) . '</p>';
  $page['header']['#markup'] .= '<p>' . t('Below is a list of blocks with Authcache settings for the current default theme: <strong>@theme</strong>', array('@theme' => $theme->info['name'])) . '</p>';

  module_load_include('inc', 'block', 'block.admin');

  // Get all blocks for the default theme.
  $blocks = block_admin_display_prepare_blocks($theme->name);

  $rows = array();

  foreach ($blocks as $block) {
    $block_id = $block['module'] . '-' . $block['delta'];
    $options = variable_get('authcache_block-' . $block_id, array());
    $options += authcache_p13n_config_defaults();

    // Load blocks that have Authcache settings enabled.
    if (isset($options['status']) && $options['status'] == '1') {
      $lifetime = format_interval($options['lifespan']);
      $region = $block['region'];

      // Get the Authcache client info.
      $block_clients = $options['clients'];
      uasort($block_clients, 'drupal_sort_weight');

      $client_info = authcache_p13n_client_info();
      $client_names = array();
      foreach (array_keys($block_clients) as $key) {
        if (!empty($client_info[$key]['title'])) {
          $client_names[] = $client_info[$key]['title'];
        }
      }

      // Build the data rows.
      $rows[] = array(
        l($block['info'], 'admin/structure/block/manage/' . $block['module'] . '/' . $block['delta'] . '/configure', array('query' => array('destination' => 'admin/config/system/authcache/blocks'))),
        implode(', ', $client_names),
        $lifetime,
        $region,
      );
    }
  }

  // Build the table display.
  if (!empty($rows)) {
    $header = array(t('Block'), t('Client'), t('Cache Lifetime'), t('Region'));
    $page['table']['#markup'] = theme('table', array(
      'header' => $header,
      'rows' => $rows,
      'attributes' => array(
        'id' => 'authcache-blocks',
      ),
    ));
  }

  $page['footer']['#markup'] = '<em>' . t('To add a block to the list of personalized blocks, visit the !blocks page and click "configure" next to the block in question.', array('!blocks' => l(t('Blocks'), 'admin/structure/block'))) . '</em>';
  return $page;
}
