<?php
/**
 * @file
 * Stub classes for testing.
 */

/**
 * Stub router.
 */
class AuthcacheP13nTestRequestRouterStub implements AuthcacheP13nRequestRouterInterface {
  /**
   * {@inheritdoc}
   */
  public function exists($route_id) {
    return in_array($route_id, array(
      'test/good',
      'test/bad',
    ));
  }

  /**
   * {@inheritdoc}
   */
  public function getHandler($route_id) {
    switch ($route_id) {
      case 'test/good':
        return new AuthcacheP13nTestRequestHandlerStub();

      case 'test/bad':
        return new AuthcacheP13nTestRequestHandlerBadStub();

      default:
        return FALSE;
    }
  }

  /**
   * {@inheritdoc}
   */
  public function generateURL($route_id, $arg = NULL) {
    if ($route_id == 'test/bad') {
      return FALSE;
    }
    else {
      return url('http://example.com/authcache.php', array(
        'absolute' => TRUE,
        'query' => array(
          'r' => $route_id,
          'a' => $arg ?: '',
        ),
      ));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function rebuild() {
  }
}

/**
 * Stub request handler.
 */
class AuthcacheP13nTestRequestHandlerStub implements AuthcacheP13nRequestHandlerInterface {
  /**
   * {@inheritdoc}
   */
  public function handle($params) {
    print serialize($params);
  }
}

/**
 * Stub request handler.
 */
class AuthcacheP13nTestRequestHandlerBadStub implements AuthcacheP13nRequestHandlerInterface {
  /**
   * {@inheritdoc}
   */
  public function handle($params) {
    print 'this line is expected to be discarded';
    switch ($params['error']) {
      case 'not_found':
        throw new AuthcacheP13nRequestNotFound();

      case 'invalid_input':
        throw new AuthcacheP13nRequestInvalidInput();

      case 'access_denied':
        throw new AuthcacheP13nRequestAccessDenied();

      case 'server_error':
        throw new AuthcacheP13nRequestException();

      default:
        throw new Exception();
    }
  }
}

/**
 * Stub URL generator.
 */
class AuthcacheP13nTestRequestUrlGeneratorStub implements AuthcacheP13nRequestUrlGeneratorInterface {
  /**
   * {@inheritdoc}
   */
  public function url($route_id, $arg = NULL) {
    if ($route_id == 'test/bad') {
      return FALSE;
    }
    else {
      return url('http://example.com/authcache.php', array(
        'absolute' => TRUE,
        'query' => array(
          'r' => $route_id,
          'a' => $arg ?: '',
        ),
      ));
    }
  }
}
