<?php
/**
 * @file
 * Defines personalization fragment for views
 */

/**
 * Personalization fragment for rendered views.
 */
class AuthcacheViewsFragment implements AuthcacheP13nFragmentInterface, AuthcacheP13nFragmentValidatorInterface {
  /**
   * {@inheritdoc}
   */
  public function validate($keys) {
    $result = array();

    foreach ($keys as $key) {
      $parts = json_decode($key, TRUE);

      if (empty($parts['name'])) {
        authcache_p13n_validation_error('Views: missing name');
      }
      $name = $parts['name'];

      if (empty($parts['display'])) {
        authcache_p13n_validation_error('Views: missing display');
      }
      $display = $parts['display'];

      $args = empty($parts['args']) ? array() : $parts['args'];

      $result[$key] = array(
        'name' => $name,
        'display' => $display,
        'args' => $args,
      );
    }

    return $result;
  }

  /**
   * {@inheritdoc}
   *
   * @see views_embed_view()
   */
  public function render($key, $param) {
    $view = views_get_view($param['name']);
    if (!$view || !$view->access($param['display'])) {
      return;
    }

    return $view->preview($param['display'], $param['args']);
  }
}
